coherence.upnp.services.servers.connection_manager_server (module) — Cohen3 0.8.0 documentation

# coherence.upnp.services.servers.connection_manager_server (module)

## Connection Manager service

class `ConnectionManagerControl`(server)

  Bases: `coherence.upnp.core.service.ServiceControl`, `coherence.upnp.core.soap_service.UPnPPublisher`

class `ConnectionManagerServer`(device, backend=None)

  Bases: `coherence.upnp.core.service.ServiceServer`, `twisted.web.resource.Resource`

  `logCategory` = 'connection_manager_server'
  `release`()
  `add_connection`(RemoteProtocolInfo, Direction, PeerConnectionID, PeerConnectionManager)
  `remove_connection`(id)
  `remove_lingering_connections`()

    Check if we have a connection that hasn’t a StateVariable change within the last 300 seconds, if so remove it.

  `lookup_connection`(id)
  `lookup_avt_id`(id)
  `lookup_rcs_id`(id)
  `listchilds`(uri)
  `render`(request)

    Render a given resource. See L{IResource}’s render method.

    I delegate to methods of self with the form ‘render_METHOD’ where METHOD is the HTTP that was used to make the request. Examples: render_GET, render_HEAD, render_POST, and so on. Generally you should implement those methods instead of overriding this one.

    render_METHOD methods are expected to return a byte string which will be the rendered page, unless the return value is C{server.NOT_DONE_YET}, in which case it is this class’s responsibility to write the results using C{request.write(data)} and then call C{request.finish()}.

    Old code that overrides render() directly is likewise expected to return a byte string or NOT_DONE_YET.

    @see: L{IResource.render}

  `set_variable`(instance, variable_name, value, default=False)
  `upnp_PrepareForConnection`(*args, **kwargs)
  `upnp_ConnectionComplete`(*args, **kwargs)
  `upnp_GetCurrentConnectionInfo`(*args, **kwargs)